@@ -40,7 +40,10 @@ cran_load <- function(pkgname){
     
   #check if package has been installed
   if(!file.exists(pkgpath)){
-    stop("Package installation of ", pkgname, " was unsuccessful.\n\n", paste(output, collapse="\n"));
+    #note that stop() might not work because error message is too large (install log)
+    header <- paste("Package installation of", pkgname, "was unsuccessful.\n\n");
+    msg <- paste(output, collapse="\n");
+    res$error(paste(header, msg, sep="\n"));
   }
 
   #return the path 
